#!/bin/bash

## Informations de version
version="2.4.14"
date="19/10/22"


###################################################
# Adresse MAC de l'enceinte bluetooth (à modifier)
#MAC="B8:D5:0B:CB:D4:5D"  # JBL Flip 3
#MAC="F8:5C:7D:FD:ED:FF" #JBL Go
MAC="04:52:C7:4E:B4:39" # Bose Mini
###################################################


# Aliases pour voix espeak-ng
esp1="/usr/bin/espeak-ng -s 110 -v mb/mb-fr1"
esp2="/usr/bin/espeak-ng -s 110 -v mb/mb-fr2"


# Nettoyage des fichiers temporaires
rm -f /tmp/input.sh.* &>/dev/null
rm -f /tmp/volume.sh.* &>/dev/null
rm -f /tmp/concatenation.txt &>/dev/null
rm -f /tmp/bluetooth_status

# Définition des fichiers temporaires
conc="/tmp/concatenation.txt" # concaténation
last="/tmp/phrase.txt"		# dernière phrase
error="/tmp/error.txt"		# erreur de frappe
bluetooth="/tmp/bluetooth_status"  # connexion bluetooth

# beep
function beep(){
	( speaker-test -t sine -f 1000  & pid=$! ; sleep 0.1s ; kill -9 $pid) &>/dev/null
}
function beep_long(){
	( speaker-test -t sine -f 1000 & pid=$! ; sleep 1s ; kill -9 $pid) &>/dev/null 
}

# Connexion Bluetooth

function active_bluetooth(){
dialog --backtitle "Bluetooth" --title "Connexion à l'enceinte bluetooth" --infobox "\n\nConnexion à l'enceinte bluetooth..." 10 60
$esp2 "connexion à l'enceinte bloutouss" 

# Activation du controleur
bt_power="`bluetoothctl show | grep 'Powered: yes'`"
if [ -z "$bt_power" ] ;then
bluetoothctl power on &>/dev/null
fi
# Connnexion et test succès
bluetoothctl connect $MAC &>$bluetooth 
sleep 3
if [ ! -z  "`cat $bluetooth |grep 'Connection successful'`" ] ; then
	
	# Récupération du nom de flux
	SINK="`pacmd list-sinks | grep "name:" | grep "blu" | cut -f2 -d\< | cut -f1 -d\>`"

	# Flux BT par défaut
	pacmd set-default-sink $SINK	
	
	# Volume de l'enceinte
	amixer set Master 20% &>/dev/null
	$esp2 "Enceinte bloutouss connectée" &
	sleep 3 
else
	amixer set Master 60% &>/dev/null
	$esp2 "Enceinte bloutouss non connectée" &
	sleep 2
fi
}

active_bluetooth


 
# Accueil vocal
$esp2 "Menu principal. Pour l'aide, tapez sur : h,  puis : Entrée." &

# Stockage de l'entrée
INPUT=/tmp/input.sh.$$
VOLUME=/tmp/volume.sh$$

############################################################################
## Fonctions d'aide
############################################################################

# Aide principale
function aide_principale(){
killall espeak-ng 2> /dev/null
sleep 1
$esp2 "Aide du menu principal.
sleep 0.5
Pour reconnecter l'enceinte bloutouss, tapez b, t, Entrée. 
Pour corriger un mot, tapez : c, Entrée.
Pour reconstituer la phrase, tapez : Espace, Entrée.
Pour répéter la dernière phrase, tapez : Espace, Espace, Entrée.
Pour un bip long, tapez : b, Entrée.
Pour régler le volume, tapez : v, v, Entrée.
Pour l'aide sur les raccourcis, tapez :  r, r, Entrée.
Pour l'aide sur les commandes, tapez :  c,  c, Entrée.
Tapez sur : Entrée, pour revenir au menu principal." &

dialog --colors --title "Aide du menu principal" --msgbox " 
\n
Toutes les saisies clavier doivent être suivies par\Z1\Zb Entrée\Zn.\n
\n
\Z1\Zbbt\Zn : Reconnexion bluetooth.\n
\Z1\Zbc\Zn : correction.\n
\Zb\Z1Espace\Zn : assemblage de la phrase. \n
\Zb\Z1Espace Espace\Zn : répétition.\n
\Zb\Z1b\Zn : bip long. \n
\Zb\Z1vv\Zn : réglage du volume. \n
\Zb\Z1rr\Zn : aide des raccourcis.\n
\Zb\Z1cc\Zn : aide des commandes .\n
" 20 60

killall espeak-ng 2>/dev/null
beep 
}

# Commandes
function aide_commandes(){
killall espeak-ng 2>/dev/null
$esp2 "
Aide des commandes.
Pour une introduction, tapez : i, i, puis Entrée.
Pour la date, tapez : d, d, puis Entrée.
Pour l'heure, tapez : h, h, puis Entrée.
Pour la charge de la batterie, tapez : b, b, puis Entrée.
Pour tester la connexion internet, tapez : n, n, puis Entrée.
Pour revenir au menu principal, appuyez sur Entrée." &

dialog --colors --title "Aide des commandes" --msgbox \
	"
\n
\Zb\Z1ii\Zn : introduction.\n
\Zb\Z1dd\Zn : date.\n
\Zb\Z1hh\Zn : heure.\n
\Zb\Z1bb\Zn : charge batterie.\n
\Zb\Z1nn\Zn : test réseau.\n
\n 
Pour revenir au menu principal, appuyez sur : \Z1\ZbEntrée\Zn." 20 60
killall espeak-ng 2> /dev/null
beep 
sleep 1
$esp2 "Menu principal" &
}

# Raccourcis saisie
function aide_raccourcis(){
	killall espeak-ng 2> /dev/null # Stoppe un message antérieur
$esp2 "Aide des raccourcis.
Tapez : Entrée pour arrêter l'énumération et revenir au menu principal.
bonjour : b, j.
salut : s, l.
comment ça va : c, c, v.
au revoir : a, r, v.
adresse mail : m, l.
téléphone : t, p, h.
oui : o.
oui, merci : o , m.
non : n.
non, merci : n, m.
s'il vous plaît : s, v, p. 
s'il te plaît : s, t, p.
pourrais-tu : p, t.
pouvez-vous : p, v.
je voudrais : j, v.
je veux bien : j, v, b.
je ne veux pas : j, n, v, p.
je préfère : j, p, f.
je ne peux pas : j, n, p, p
" &
dialog --title "Aide des raccourcis" --colors --msgbox "\n Appuyez sur \Z1\ZbEntrée\Zn pour arrêter l'énumération et revenir au menu principal.
" 10 60 
killall espeak-ng 2> /dev/null
beep 
	HH=`date +%H`
	MM=`date +%M`
	$esp2 "$DD"
}

function vtime(){
# Donne l'heure en synthèse vocale
DD=`date +%A\ %d\ %B`
	HH=`date +%H`
	MM=`date +%M`
	$esp2 "Il est $HH heures $MM minutes" &
}

function intro(){
	$esp1 "Je suis non voyant, et atteint par la maladie de Charcot.
	De ce fait, je n'ai plus l'usage de la parole. J'utilise l'ordinateur pour communiquer.
	Mon cerveau fonctionne parfaitement à part ce handicap." &
}

# Charge de la batterie
function vbatt(){
DD=`date +%A\ %d\ %B`
CHARGE=`acpi|cut -f2 -d,`
	$esp2 "Charge de la batterie : $CHARGE" &
}

# test réseau
function test_rezo(){
	$esp2 "Test de connexion en cours, patientez quelques secondes..."
ping -c4 www.google.com &>/tmp/test_rezo 
VALID=`cat /tmp/test_rezo|grep "4 received"`

if [[ -n $VALID ]] ;then
	$esp2 "L'ordinateur est connecté à internet" &
else
	$esp2 "L'ordinateur n'est pas connecté à internet" &
fi
rm /tmp/test_rezo
}

function volume_master(){
	$esp2 "Réglage du volume. Entrez un nombre entre 50 et 100" &
	dialog --backtitle "Réglage du volume sonore" --title "Volume" --inputbox "\nEntrez un nombre entre 50 et 100." 10 60  2>$VOLUME
	reglage_vol=$(<"${VOLUME}")
	amixer set Master $reglage_vol'%' &>/dev/null
	$esp2 " Volume réglé à $reglage_vol pour cent." 
	$esp2 "Menu principal"
        beep 
}

# test son
function son(){
if [ -e /usr/local/share/sounds/henry2.wav ];  then
	aplay /usr/local/share/sounds/henry2.wav &>/dev/null
fi
}

##########################################################################
## Fonctions synthèse vocale
###########################################################################

# Assemble la dernière phrase
function assemble(){
	mv $conc $last
	$esp1 "`cat $last`" &
	dialog --title "Phrase complète" --infobox " \n\n\n `cat $last`" 12 50
	sleep 3
	beep 
}

# Répète la dernière phrase
function repete(){
	$esp1 "`cat $last`" &
	dialog --title "Répétition" --infobox " \n\n\n `cat $last`" 12 50
	sleep 3
	beep 
	
}

# Supprime la dernière ligne du fichier de concaténation en cas d'erreur
function /decorrige(){
	mv $conc $error
	tac $error | sed '1d' | tac > $conc
	rm $error
	$esp2 "correction" &
}

#####################################################################
## Menu principal
#####################################################################

# Boucle infinie
while true
do
dialog --colors --backtitle "main.sh $version - $date - Jack Good software inc." --title "Accueil" --inputbox \
"
\n
\Z1\ZbEntrée\Zn : synthèse des mots saisis au clavier\n
\Z1\Zbh\Zn      : aide. \n
\Z1\Zbstartx\Zn	: interface graphique (configuration wifi). \n
\Z1\Zbexit\Zn 	 : quitter le programme. 
" 10 60 2>"${INPUT}"

texte=$(<"${INPUT}")

# Decision

case $texte in

# Les raccourcis
	k) killall -9 espeak-ng 
		;;
	bj) $esp1 "bonjour" &
		echo "bonjour" >> $conc 
		;;
	ccv) $esp1 "comment ça va ?" & 
	       echo "comment ça va ?" >> $conc 
	       ;;
	arv) $esp1 "au revoir" & 
		echo "au revoir" >> $conc 
		;;
	sl) $esp1 "salut" & 
	       echo "salut" >> $conc 
	       ;;
	o) $esp1 "oui"  &
		echo "oui" >> $conc 
		;;
	n) $esp1 "non" & 
		echo "non" >> $conc 
		;;
	nm) $esp1 "non, merci." 
		echo "non, merci" >> $conc 
		;;
	om) $esp1 "oui, merci." & 
		echo "oui, merci" >> $conc 
		;;
	stp) $esp1 "s'il te plaît" & 
		echo "s'il te plaît" >> $conc 
		;;
	svp) $esp1 "s'il vous plaît"  &
		echo "s'il vous plaît" >> $conc 
		;;
	pt) $esp1 "pourrais-tu" &
		echo "pourrais-tu" >> $conc
		;;
	pv) $esp1 "pouvez-vous" &
		echo "pouvez-vous" >> $conc 
		;;
        jv) $esp1 "je voudrais" &
		echo "je voudrais" >> $conc 
		;;
	jvb) $esp1 "je veux bien" &
		echo "je veux bien" >> $conc 
		;;
	jpf) $esp1 "je préfère" & 
		echo "je préfère" >> $conc 
		;;
	jnvp) $esp1 "je ne veux pas" &
		echo "je ne veux pas" >> $conc 
		;;
	jnpp) $esp1 "je ne peux pas" &
		echo "je ne peux pas" >> $conc 
		;;
	startx) startx; 
		$esp2 "retour en mode console, menu principal" & 
		;;
	bt) bluetoothctl disconnect $MAC &>/dev/null
	    active_bluetooth 	
	    ;;
	ii) intro ;;
	b) beep_long  ;;
	h) aide_principale ;;
	cc) aide_commandes ;;
	rr) aide_raccourcis ;;
        bb) vbatt ;;
	hh) vtime ;;
	dd) vdate ;;
	nn) test_rezo ;;
	ss) son ;;
	vv) volume_master ;;
	exit) clear 
		killall espeak-ng 2> /dev/null
		beep 
		sleep 1
		bluetoothctl disconnect $MAC
		$esp2 "Mode console. Tapez : menu pour relancer l'application." &
		echo "******************************************"
		echo "Tapez \"menu.sh\" pour relancer l'application"
		echo "******************************************"
		echo " "
		echo " "
		exit 0 
		;;
	\ ) echo "." >> $conc
		assemble
		;;	
	\ \ ) repete
		;;
	c) corrige
		;;
	*) 	$esp1 "$texte" &
		echo "$texte" >> $conc
	       ;; 
esac
done
